/**
 ******************************************************************************
 * @file    I2CDriverVtbl.h
 * @author  STMicroelectronics - ST-Korea - MCD Team
 * @version 1.2.0
 * @date    Sep 22, 2016
 *
 * @brief   I2CDriver virtual functions.
 *
 * This file declares the virtual functions overloaded by the I2CDriver.
 *
 ******************************************************************************
 * @attention
 *
 * <h2><center>&copy; COPYRIGHT 2016 STMicroelectronics</center></h2>
 *
 * Licensed under MCD-ST Liberty SW License Agreement V2, (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 *        http://www.st.com/software_license_agreement_liberty_v2
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ******************************************************************************
 */

#ifndef INCLUDE_DRIVERS_I2CDRIVERVTBL_H_
#define INCLUDE_DRIVERS_I2CDRIVERVTBL_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @sa IDrvInit
 */
sys_error_code_t I2CDrvInit(IDriver *this, void *pParams);

/**
 * Enable the IRQ line. Note that the read and write operation are managed in interrupt mode.
 *
 * @sa IDrvStart
 */
sys_error_code_t I2CDrvStart(IDriver *this);

/**
 * Disable the the IRQ line but does't disable the peripheral.
 * Note that the read and write operation are managed in interrupt mode.
 *
 * @sa IDrvStop
 */
sys_error_code_t I2CDrvStop(IDriver *this);

/**
 * Disable the peripheral in `INACTIVE` and `SLEEP_2` mode, and enable and re-initialize the peripheral in
 * `RUN` mode.
 *
 * @sa IDrvDoEnterPowerMode
 */
sys_error_code_t I2CDrvDoEnterPowerMode(IDriver *this, const EPowerMode eActivePowerMode, const EPowerMode eNewPowerMode);

/**
 * Transmit in master/slave mode nDataSize bytes of data in no-blocking mode with interrupt.
 * The target device address is nChannel.
 *
 * @param nChannel is not used in slave mode.
 *
 * @sa IDrvWrite
 */
sys_error_code_t I2CDrvWrite(IDriver *this, uint8_t *pDataBuffer, uint16_t nDataSize, uint16_t nChannel);

/**
 * Receive in master/slave mode nDataSize bytes of data in no-blocking mode with interrupt.
 * The target device address is nChannel.
 *
 * @param nChannel is not used in slave mode.
 *
 * @sa IDrvRead
 */
sys_error_code_t I2CDrvRead(IDriver *this, uint8_t *pDataBuffer, uint16_t nDataSize, uint16_t nChannel);


#ifdef __cplusplus
}
#endif


#endif /* INCLUDE_DRIVERS_I2CDRIVERVTBL_H_ */
